@@ -49,24 +49,6 @@ if os.getenv("PROJ_LIB") is None or os.getenv("PROJ_LIB") == "PROJ_LIB":
                 fid.write("# Placeholder for epsg data")
 
 
-# Hack to fix missing PROJ4 env var in root environment
-import os
-import setuptools
-
-
-if os.getenv("PROJ_LIB") is None or os.getenv("PROJ_LIB") == "PROJ_LIB":
-    conda_file_dir = setuptools.__file__
-    conda_dir = conda_file_dir.split('lib')[0]
-    proj_lib = os.path.join(os.path.join(conda_dir, 'share'), 'proj')
-    os.environ["PROJ_LIB"] = proj_lib
-    if not os.path.exists(proj_lib):
-        os.makedirs(proj_lib)
-        epsg_file = os.path.join(proj_lib, 'epsg')
-        if not os.path.exists(epsg_file):
-            with open(os.path.join(proj_lib, 'epsg'), 'w') as fid:
-                fid.write("# Placeholder for epsg data")
-
-
 import argparse
 import copy
 import functools
@@ -81,6 +63,7 @@ import shutil
 import sys
 import types
 import fs
+import warnings
 
 from mslib import __version__
 from mslib.msui.mss_qt import ui_mainwindow as ui
@@ -347,7 +330,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
                         self._exported_plugins, type(ex), ex)))
                 continue
             try:
-                    self.add_export_filter(name, extension, getattr(imported_module, function), pickertype=picker_type)
+                self.add_export_filter(name, extension, getattr(imported_module, function), pickertype=picker_type)
             # wildcard exception to be resilient against error introduced by user code
             except Exception as ex:
                 logging.error(u"Error on installing plugin: %s: %s", type(ex), ex)
@@ -724,6 +707,13 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
 
 
 def main():
+    pyversion = platform.python_version()
+    warnings.simplefilter("always")
+    if pyversion.startswith('2'):
+        warnings.warn(
+            'You are using Python {}, which will no longer be supported in mss 1.8.0'.format(pyversion),
+            DeprecationWarning
+        )
     try:
         prefix = os.environ["CONDA_DEFAULT_ENV"]
     except KeyError:
