@@ -33,6 +33,8 @@ from __future__ import absolute_import
 # Hack to fix missing PROJ4 env var in root environment
 import os
 import setuptools
+import warnings
+import platform
 
 
 if os.getenv("PROJ_LIB") is None or os.getenv("PROJ_LIB") == "PROJ_LIB":
@@ -49,24 +51,6 @@ if os.getenv("PROJ_LIB") is None or os.getenv("PROJ_LIB") == "PROJ_LIB":
                 fid.write("# Placeholder for epsg data")
 
 
-# Hack to fix missing PROJ4 env var in root environment
-import os
-import setuptools
-
-
-if os.getenv("PROJ_LIB") is None or os.getenv("PROJ_LIB") == "PROJ_LIB":
-    conda_file_dir = setuptools.__file__
-    conda_dir = conda_file_dir.split('lib')[0]
-    proj_lib = os.path.join(os.path.join(conda_dir, 'share'), 'proj')
-    os.environ["PROJ_LIB"] = proj_lib
-    if not os.path.exists(proj_lib):
-        os.makedirs(proj_lib)
-        epsg_file = os.path.join(proj_lib, 'epsg')
-        if not os.path.exists(epsg_file):
-            with open(os.path.join(proj_lib, 'epsg'), 'w') as fid:
-                fid.write("# Placeholder for epsg data")
-
-
 import paste.httpserver
 import argparse
 import logging
@@ -78,6 +62,13 @@ from mslib.utils import setup_logging
 
 
 def main():
+    pyversion = platform.python_version()
+    warnings.simplefilter("always")
+    if pyversion.startswith('2'):
+        warnings.warn(
+            'You are using Python {}, which will no longer be supported in mss 1.8.0'.format(pyversion),
+            DeprecationWarning
+        )
     parser = argparse.ArgumentParser()
     parser.add_argument("-v", "--version", help="show version", action="store_true", default=False)
     parser.add_argument("--host", help="hostname",
