@@ -55,6 +55,8 @@ import paste
 import paste.request
 import paste.util.multidict
 import urllib.parse
+import warnings
+import platform
 from chameleon import PageTemplateLoader
 
 try:
@@ -511,6 +513,13 @@ app = WMSServer()
 
 
 def application(environ, start_response):
+    pyversion = platform.python_version()
+    warnings.simplefilter("always")
+    if pyversion.startswith('2'):
+        warnings.warn(
+            'You are using Python {}, which will no longer be supported in mss 1.8.0'.format(pyversion),
+            DeprecationWarning
+        )
     try:
         query = CaseInsensitiveMultiDict(paste.request.parse_dict_querystring(environ))
         logging.debug(u"ENVIRON: %s", environ)
